==> meteor-react-materializecss-1.0.24.tgz: package/src/components/dialogs/ConfirmButton.jsx <==
import React, {Component, useEffect, useRef} from "react";
import {Random} from "meteor/random";
import M from "materialize-css";
import {i18n} from 'meteor/universe:i18n';

class ConfirmButton extends Component {
    componentDidMount() {
        const options = {
            inDuration: 250,
            outDuration: 250,
            opacity: 0.5,
            dismissible: false,
            startingTop: "4%",
            endingTop: "10%"
        };
        M.Modal.init(this.Modal, options);

        // let instance = M.Modal.getInstance(this.Modal);
        // instance.open();
        // instance.close();
        // instance.destroy();
    }

    componentWillUnmount() {
        //console.log('---unmount---')
        if (this.Modal) {
            const instance = M.Modal.getInstance(this.Modal);
            instance.close();
            instance.destroy();
        }
    }

    render() {
        const header = this.props.header || '';
        const question = this.props.question || null;
        const id = 'modal' + Random.id();
        const label = this.props.label || null;
        const actionYes = this.props.actionYes || null;
        const actionNo = this.props.actionNo || null;
        const buttonClassName = this.props.buttonClassName || ''
        const T = i18n.createComponent();

        return (
            <div>
                <a href={'#'}
                   className={"modal-trigger " + buttonClassName}
                   data-target={id}
                >{label}</a>
                <div
                    ref={Modal => {
                        this.Modal = Modal;
                    }}
                    id={id}
                    className="modal"
                >
                    {/* If you want Bottom Sheet Modal then add
                        bottom-sheet class to the "modal" div
                        If you want Fixed Footer Modal then add
                        modal-fixed-footer to the "modal" div*/}
                    <div className="modal-content">
                        <h4>{header}</h4>
                        <p>{question}</p>
                    </div>
                    <div className="modal-footer">
                        <a className="modal-close waves-effect waves-red btn btn-danger" onClick={event => {
                            if (actionNo) {
                                actionNo();
                            }
                        }}><T>messages.no</T></a>
                        <a className="modal-close waves-effect waves-green btn btn-success"
                           style={{marginLeft: '15px'}}
                           onClick={event => {
                               if (actionYes) {
                                   actionYes();
                               }
                           }}><T>messages.yes</T></a>
                    </div>
                </div>
            </div>
        );
    }
}

export default ConfirmButton;

==> meteor-react-materializecss-1.0.25.tgz: package/src/components/dialogs/ConfirmButton.jsx <==
import React, {Component, useEffect, useRef} from "react";
import {Random} from "meteor/random";
import M from "materialize-css";
import {i18n} from 'meteor/universe:i18n';

class ConfirmButton extends Component {
    componentDidMount() {
        const options = {
            inDuration: 250,
            outDuration: 250,
            opacity: 0.5,
            dismissible: false,
            startingTop: "4%",
            endingTop: "10%"
        };
        M.Modal.init(this.Modal, options);

        // let instance = M.Modal.getInstance(this.Modal);
        // instance.open();
        // instance.close();
        // instance.destroy();
    }

    componentWillUnmount() {
        //console.log('---unmount---')
        if (this.Modal) {
            const instance = M.Modal.getInstance(this.Modal);
            instance.close();
            instance.destroy();
        }
    }

    render() {
        const header = this.props.header || '';
        const question = this.props.question || null;
        const id = 'modal' + Random.id();
        const label = this.props.label || null;
        const actionYes = this.props.actionYes || null;
        const actionNo = this.props.actionNo || null;
        const buttonClassName = this.props.buttonClassName || '';

        return (
            <div>
                <a href={'#'}
                   className={"modal-trigger " + buttonClassName}
                   data-target={id}
                >{label}</a>
                <div
                    ref={Modal => {
                        this.Modal = Modal;
                    }}
                    id={id}
                    className="modal"
                >
                    {/* If you want Bottom Sheet Modal then add
                        bottom-sheet class to the "modal" div
                        If you want Fixed Footer Modal then add
                        modal-fixed-footer to the "modal" div*/}
                    <div className="modal-content">
                        <h4>{header}</h4>
                        <p>{question}</p>
                    </div>
                    <div className="modal-footer">
                        <a className="modal-close waves-effect waves-red btn btn-danger" onClick={event => {
                            if (actionNo) {
                                actionNo();
                            }
                        }}>{ i18n.__('messages.no') }</a>
                        <a className="modal-close waves-effect waves-green btn btn-success"
                           style={{marginLeft: '15px'}}
                           onClick={event => {
                               if (actionYes) {
                                   actionYes();
                               }
                           }}>{i18n.__('messages.yes') }</a>
                    </div>
                </div>
            </div>
        );
    }
}

export default ConfirmButton;
